NextUtils class

Constructors

NextUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getAllColValues(String sizes) → Map<String, int>
Get values from string
getAllOffsetsValue(String sizes) → Map<String, int>
Get offsets values from string
getMaxWidth(String sizes, {required BuildContext context, bool isOffset = false, double? width}) → double
Returns what is the current prefix based on width
getMaxWidthForNonFluid(double width) → double
Returns the width for non-fluid containers based on a given width
getPrefixByWidth(double width) → String
Returns what is the current prefix based on width
getPrefixEnumByWidth(double width) → GridPrefixes
Returns Current GridPrefix