NextAlertColorUtils class

Constructors

NextAlertColorUtils({required Color color, required Color backgroundColor, required Color borderColor})
const

Properties

backgroundColor → Color
Define background color of NextAlert
final
borderColor → Color
Define Border color of NextAlert
final
color → Color
Define primary color of NextAlert
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited