NextAlert class

Inheritance
Available extensions

Constructors

NextAlert({Key? key, bool visible = true, BorderRadiusGeometry borderRadius = const BorderRadius.all(Radius.circular(4)), Widget? trailing, Widget? heading, void onClosedIconPressed()?, NextVariant variant = NextVariant.primary, TextStyle? textStyle, double verticalHeadingSpace = 10.0, TextStyle? headingTextStyle, NextAlertColorUtils? customConfigs, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Widget? child, Widget transitionBuilder(Widget, Animation<double>)?})
Construct NextAlert
const

Properties

borderRadius → BorderRadiusGeometry
BorderRadius for box
final
child → Widget?
define child NextAlert
final
customConfigs → NextAlertColorUtils?
Custom Configs for alert works only when variant is custom
final
hashCode → int
The hash code for this object.
no setterinherited
heading → Widget?
define heading NextAlert
final
headingTextStyle → TextStyle?
define headingTextStyle NextAlert
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
define margin NextAlert
final
onClosedIconPressed → void Function()?
on trailing button pressed
final
padding → EdgeInsetsGeometry?
define padding NextAlert
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
define textStyle NextAlert
final
trailing → Widget?
By default trailing will be close button
final
transitionBuilder → Widget Function(Widget, Animation<double>)?
Closing transition builder
final
variant → NextVariant
define style NextAlert
final
verticalHeadingSpace → double
Space between heading and child
final
visible → bool
define visibility NextAlert
final

Methods

addDecoration(BoxDecoration decoration) → Widget

Available on Widget, provided by the WidgetExtensions extension

aspectRatio({Key? key, required double aspectRatio}) → Widget

Available on Widget, provided by the WidgetExtensions extension

bounce({Duration duration = const Duration(milliseconds: 350), Duration delay = Duration.zero, AnimationController? controller, bool startAnimation = true, double initialPosition = 100, bool loop = false, double viewPort = 0.1, NextBounceVariant variant = NextBounceVariant.bounceInLeft}) → Widget

Available on Widget, provided by the AnimationExtension extension

boxShadow({Key? key, Color color = const Color(0xFF000000), Offset offset = Offset.zero, double blurRadius = 0.0, double spreadRadius = 0.0, bool animate = false}) → Widget

Available on Widget, provided by the WidgetExtensions extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center({Key? key, double? widthFactor, double? heightFactor}) → Widget

Available on Widget, provided by the WidgetExtensions extension

clipOval({Key? key, CustomClipper<Rect>? clipper, Clip clipBehavior = Clip.antiAlias}) → Widget

Available on Widget, provided by the WidgetExtensions extension

clipRect({Key? key, CustomClipper<Rect>? clipper, Clip clipBehavior = Clip.hardEdge}) → Widget

Available on Widget, provided by the WidgetExtensions extension

clipRRect({Key? key, double? all, double? topLeft, double? topRight, double? bottomLeft, double? bottomRight, CustomClipper<RRect>? clipper, Clip clipBehavior = Clip.antiAlias, bool animate = false}) → Widget

Available on Widget, provided by the WidgetExtensions extension

container({Key? key, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, Color? color, Decoration? decoration, Decoration? foregroundDecoration, double? width, double? height, BoxConstraints? constraints, EdgeInsetsGeometry? margin, Matrix4? transform, AlignmentGeometry? transformAlignment, Clip clipBehavior = Clip.none, bool shouldAnimate = false, Duration animationDuration = const Duration(milliseconds: 450)}) → Widget

Available on Widget, provided by the WidgetExtensions extension

createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
customPadding({Key? key, double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget

Available on Widget, provided by the PaddingExtension extension

debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fadeIn({Duration duration = const Duration(milliseconds: 350), Duration delay = Duration.zero, AnimationController? controller, bool startAnimation = true, bool loop = false, double viewPort = 0.1, double initialPosition = 100, NextFadeInVariant variant = NextFadeInVariant.fadeInLeft}) → Widget

Available on Widget, provided by the AnimationExtension extension

fadeOut({Duration duration = const Duration(milliseconds: 350), Duration delay = Duration.zero, AnimationController? controller, bool startAnimation = true, double initialPosition = 100, bool loop = false, double viewPort = 0.1, NextFadeOutVariant variant = NextFadeOutVariant.fadeOutLeft}) → Widget

Available on Widget, provided by the AnimationExtension extension

fittedBox({Key? key, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center}) → Widget

Available on Widget, provided by the WidgetExtensions extension

flexible({Key? key, int flex = 1, FlexFit fit = FlexFit.loose}) → Widget

Available on Widget, provided by the WidgetExtensions extension

flip({Duration duration = const Duration(milliseconds: 350), Duration delay = Duration.zero, AnimationController? controller, bool startAnimation = true, bool loop = false, double viewPort = 0.1, NextFlipVariant variant = NextFlipVariant.flipX}) → Widget

Available on Widget, provided by the AnimationExtension extension

fractionallySizedBox({Key? key, AlignmentGeometry alignment = Alignment.center, double? widthFactor, double? heightFactor}) → Widget

Available on Widget, provided by the WidgetExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(void onDoubleTap(), {bool autoFocus = false}) → Widget

Available on Widget, provided by the GestureExtension extension

onLongPress(void onLongPress(), {bool autoFocus = false}) → Widget

Available on Widget, provided by the GestureExtension extension

onTap(void onTap(), {bool autoFocus = false}) → Widget

Available on Widget, provided by the GestureExtension extension

pad(double padding, {Key? key}) → Widget

Available on Widget, provided by the PaddingExtension extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0, Key? key}) → Widget

Available on Widget, provided by the PaddingExtension extension

safeArea({Key? key, bool left = true, bool top = true, bool right = true, bool bottom = true, EdgeInsets minimum = EdgeInsets.zero, bool maintainBottomViewPadding = false}) → Widget

Available on Widget, provided by the WidgetExtensions extension

sizedBox({Key? key, double? width, double? height}) → Widget

Available on Widget, provided by the WidgetExtensions extension

slide({Duration duration = const Duration(milliseconds: 350), Duration delay = Duration.zero, AnimationController? controller, bool loop = false, double viewPort = 0.1, bool startAnimation = true, double initialPosition = 100, NextSlideVariant variant = NextSlideVariant.slideInLeft}) → Widget

Available on Widget, provided by the AnimationExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
zoom({Duration duration = const Duration(milliseconds: 350), Duration delay = Duration.zero, AnimationController? controller, bool startAnimation = true, bool loop = false, double viewPort = 0.1, double initialPosition = 1, NextZoomVariant variant = NextZoomVariant.zoomIn}) → Widget

Available on Widget, provided by the AnimationExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited